@@ -335,7 +335,7 @@ def reindex_interp(data, method='linear', copy=True, interpolate_kws={'fill_valu
             args = np.array([data[k].data for k in data.dims])
             values = data.values
             fi = URegularGridInterpolator(tuple(args), values, method=method, **interpolate_kws)
-            newpts = np.array(meshgrid(*[ds[k].data for k in ds.dims])).T.reshape(-1, ds.ndim)
+            newpts = np.array(np.meshgrid(*[ds[k].data for k in ds.dims])).T.reshape(-1, ds.ndim)
         # perform actual interpolation
         ds.values = fi(newpts).reshape(ds.shape)
     else:
