@@ -26,6 +26,7 @@ from omfit_classes.omfit_json import OMFITjson, OMFITsettings, SettingsName
 from omfit_classes.omfit_omas_utils import setup_hardware_overlay_cx, add_hardware_to_ods
 from omfit_classes.omfit_formatter import omfit_formatter
 from omfit_classes.utils_fusion import is_device
+from omfit_classes.omfit_mds import translate_MDSserver
 
 __all__ = ['efitviewer']
 
@@ -43,6 +44,10 @@ omas_features = {
 }
 
 
+class EfitviewerDataError(doNotReportException, ValueError):
+    """There is a problem with the data needed to make efitviewer work"""
+
+
 # Shortcuts and utilities for defining key information, data structure, and shortcuts -----------------------------
 def efitviewer():
     """Shortcut for launching efitviewer"""
@@ -143,7 +148,7 @@ def add_command_box_tab():
 
 
 # Data loading and related helpers --------------------------------------------------------------------------------
-def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0):
+def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0, no_empty=None):
     """
     Puts an ODS with CX info in the tree
 
@@ -190,6 +195,8 @@ def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0
         shot = def_shot
     if efitid is None:
         efitid = the_case.setdefault('efit_tree', None)
+    if no_empty is None:
+        no_empty = settings.setdefault('no_empty', True)
 
     if isinstance(gfile, str):
         gfile_str = gfile
@@ -200,17 +207,27 @@ def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0
         gfile_str = None
 
     if gfile is None:
-        load_cmd = "setup_hardware_overlay_cx({}, {}, {}, efitid={}, default_load=False)".format(
-            repr(device), repr(shot), repr(t), repr(efitid)
+        load_cmd = "setup_hardware_overlay_cx({}, {}, {}, efitid={}, default_load=False, no_empty={})".format(
+            repr(device), repr(shot), repr(t), repr(efitid), no_empty
         )
-        ods = out[ods_tag] = setup_hardware_overlay_cx(device, shot, t, efitid=efitid, default_load=False, quiet=True)
+        ods = out[ods_tag] = setup_hardware_overlay_cx(device, shot, t, efitid=efitid, default_load=False, quiet=True, no_empty=no_empty)
     else:
-        ods = out[ods_tag] = setup_hardware_overlay_cx(device, geqdsk=gfile, default_load=False, quiet=True)
-        load_cmd = "setup_hardware_overlay_cx({}, geqdsk={}, default_load=False)".format(repr(device), gfile_str)
+        ods = out[ods_tag] = setup_hardware_overlay_cx(device, geqdsk=gfile, default_load=False, quiet=True, no_empty=no_empty)
+        load_cmd = "setup_hardware_overlay_cx({}, geqdsk={}, default_load=False, no_empty={})".format(repr(device), gfile_str, no_empty)
 
     settings['cases'][index]['instructions_for_loading_ods'] = load_cmd
-    assert 'equilibrium' in ods, 'Equilibrium data should have been added to the ODS, but they are missing.'
-    assert 'time' in ods['equilibrium'], 'No time in equilibrium. It should have been added. This ODS is not okay.'
+    if 'equilibrium' not in ods or 'time' not in ods['equilibrium']:
+        error_message = (
+            f'\nFailed to populate equilibrium data in the ODS.\n'
+            f'This can happen if the data are missing from the\n'
+            f'source database or if there is a connection problem.\n'
+            f'You can try "File" > "Reset SSH tunnels, database connections".\n'
+            f'If that does not work, please verify access to the database\n'
+            f'({translate_MDSserver(device, efitid)})\n'
+            f'and check that the shot ({device}#{shot}) has data for {efitid}.'
+        )
+        ods['dataset_description.ids_properties.comment'] = error_message
+        raise EfitviewerDataError(error_message)
 
     return ods
 
@@ -628,8 +645,11 @@ def setup_special_contours(case=0, t=None, contour_quantity=None, spacing=None,
             ref_z = zmaxis
         elif space_ref.lower() in ['outer_lower_strike']:
             # omfit_omas.multi_efit_to_omas() loads strike points in a set order: low out, low in, up out, up in
-            ref_r = eq_slice['boundary.strike_point.0.r']
-            ref_z = eq_slice['boundary.strike_point.0.z']
+            try:
+                ref_r = eq_slice['boundary.strike_point.0.r']
+                ref_z = eq_slice['boundary.strike_point.0.z']
+            except ValueError:
+                ref_r = ref_z = np.NaN
             if np.isnan(ref_r) or np.isnan(ref_z):
                 raise ValueError('Outer lower strike point not defined; might be a limited shape or just missing from ODS')
         elif space_ref.lower() in ['outer_upper_strike']:
@@ -1018,8 +1038,14 @@ def plot_single_cx_ods(
 
     # noinspection PyBroadException
     try:
-        assert 'equilibrium' in ods, 'No equilibrium data. Cannot plot.'
-        assert 'time' in ods['equilibrium'], 'No time in equilibrium.'
+        if 'comment' in ods['dataset_description.ids_properties']:
+            ids_comment = 'There is a comment in the ODS:\n' + ods['dataset_description.ids_properties.comment']
+        else:
+            ids_comment = ''
+        if 'equilibrium' not in ods:
+            raise EfitviewerDataError('No equilibrium data. Cannot plot.' + ids_comment)
+        if 'time' not in ods['equilibrium']:
+            raise EfitviewerDataError('No time in equilibrium; nothing to plot.' + ids_comment)
 
         # Resolve keyword default values
         if contour_quantity is None:
