@@ -399,6 +399,8 @@ def enforce_test_report_header_in_top_comment(thread=None, **kw):
         print('Could not find an open pull request: no top comment to edit. Aborting.')
         return
     content = OMFITgithub_paged_fetcher(path='issues/{}'.format(thread), **kw).fetch()[0]['body']
+    if content is None:  # Top comment is blank
+        content = ''
     # Change line break style; otherwise the report header won't match after comment has been edited manually on GitHub.
     content = content.replace('\r\n', '\n')
     if test_report_header not in content:
